# SEMINÁŘ VÝZKUM KONFLIKTU II - SWIRL, Deskriptivní statistika a využití AI

# -----------------------------------------------------------------------------
# ČÁST 1: SWIRL DEBRIEFING ----------------------------------------------------
# ----------------------------------------------------------------------------- 

# Nějaký problém? --> prostor na poznámky/kód


# -----------------------------------------------------------------------------
# ČÁST 2: Project MARS a deskriptivní statistika ------------------------------
# ----------------------------------------------------------------------------- 
# Originální databank projektu Mars: https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/DUO7IE


getwd()
setwd("C:/Users/honza/Desktop/VK_R/Seminář II - Výzkum konfliktu") # V případě potřeby změňte working directory - WINDOWS OS
setwd("/Users/honza/Desktop/VK_R/Seminář II - Výzkum konfliktu") # MAC OS
list.files()

# Musíme vyvolat packages, které budeme potřebovat (funkce níže je nainstaluje, pokud je ještě nemáte):
packages <- c("readxl", "ggplot2", "vcov", "sandwich", "margins", "estimatr", "psych", "dplyr", "tidyverse")

for(p in packages){
  if(!require(p, character.only = TRUE)){
    install.packages(p)
    library(p, character.only = TRUE)
  }
}

ProjectMarsV1_1 <- read_excel("ProjectMarsV1.1.xlsx", na = "NA")

# ------------------------------------------------------------------------------
# (A) prozkoumání datasetu------------------------------------------------------
# ------------------------------------------------------------------------------
View(ProjectMarsV1_1)

# TIP: Z kódu lze jednoduše udělat komentář: ctrl+shift+c (Windows/Linux) a cmd+shift+c (MacOS)


# THE BIGGER PICTURE:
# --> primarily investigates the relationship between military inequality within armed forces and their battlefield performance through various lenses:
# Military Inequality Coefficient (MIC): This is a central independent variable in the analysis. The MIC encapsulates various facets of inequality within the military, including ethnic diversity, prewar regime treatment of different groups, and other related factors.
# Battlefield Performance: This serves as the dependent variable in the study. It's measured through several metrics, such as the loss-exchange ratio, mass desertion, mass defection, and the use of blocking detachments.
# The main relationship identified through this analysis suggests that greater military inequality, characterized by factors like ethnic discrimination or disparities in how different groups are treated within the armed forces, is hypothesized to adversely affect battlefield performance.


# >>> Independent Variables <<<
#-------------------------------
#   Military Inequality Coefficient (MIC)
#       MIC mean: Average of the low and high estimates of military inequality for each belligerent one year prior to war or at the eve of battle.
#       MIC bands: Operationalized as Low (0), Medium (1), High (2), and Extreme (3) based on MIC mean values.

#   Ethnic Groups
#       ngroups: Denotes the number of ethnic groups within the army at the eve of war with at least one percent representation.
#       logngroups: The number of ethnic groups (logged) within the army at the eve of war with at least one percent representation.

#   Bands of Inequality
#       MIC bands: A simplified measure categorizing military inequality into four levels for analysis.

# >>> Dependent Variables <<<
#-------------------------------
#   Loss-Exchange Ratio (LER)
#       ler_low, ler_high: For calculating low and high estimates of LER.
#       ler_mean: Average of ler_low and ler_high.
#       log_lermean: Logarithm of ler_mean.

#   Battlefield Performance Index (BPI)
#       BPI: A composite index that aggregates measures of battlefield performance, though specific calculation details or variable names are not provided in the snippet.


# Independent Variables: These include the Military Inequality Coefficient with subcategories like Ethnic Groups, Prewar Regime Treatment, and Ranges.
# Dependent Variable: Battlefield Performance, measured through variables like Loss-Exchange Ratio, Mass Desertion, Mass Defection, and Blocking Detachments.
# Additional Variables: Cover aspects like Regime Type, Material Power/Preponderance, Army Type and Recruitment, and Distance.

# ------------------------------------------------------------------------------
# (B) prozkoumání datasetu - základní deskriptiva ------------------------------
# ------------------------------------------------------------------------------

# Basic summary celého datasetu
summary(ProjectMarsV1_1)

# Basic summary jednotlivých proměnných
summary(ProjectMarsV1_1$mic_mean)

# Basic summary vybraných proměnných proměnných (psych package)
describe(ProjectMarsV1_1[c("mic_mean", "bpi", "lermean", "ngroups")])
psych::describe(ProjectMarsV1_1[c("mic_mean", "bpi", "lermean")])

# >>> Variabilita <<<
# směrodatná odchylka (SD) (Standard Deviation) - určuje, jak moc se v průměru odchylují datové body od průměru --> nízká hodnota znamená homogenitu (hodnoty jsou blízko průměru)
#     a tím i předpovídatelnost a spolehlivost datasetu, zatímco vysoká SD znamená heterogenitu (hodnoty jsou daleko od průměru a těžko se nám předpovídají 
#     a pro statistické modely je těžší spolehlivě dataset popsat a predikovat)

# Rozptyl, též střední kvadritická odchylka => SD umocněná na druhou

sd(ProjectMarsV1_1$mic_mean, na.rm = TRUE)
var(ProjectMarsV1_1$mic_mean, na.rm = TRUE) # Rozptyl se hůře interpretuje oproti SD, ale některé modely s ním pracují

# Reportování dle APA stylu: ... průměrný poměr ztrát (loss-exchange-ratio) (M = 0.20, Mdn = 0.15, SD = 0.17)

# Disribuce dat
hist(ProjectMarsV1_1$mic_mean)
hist(ProjectMarsV1_1$lermean)
hist(ProjectMarsV1_1$log_lermean) # Rozdíl mezi neupravenou hodnotou ler_mean a jejím logaritmickým vyjádřením

# ------------------------------------------------------------------------------
# (C) prozkoumání datasetu - korelace (asociace) -------------------------------
# ------------------------------------------------------------------------------

# Využijeme parametrický, nebo neparametrické testy? 
# Parametric test!
#1 Linearity: The relationship between the two variables is linear.
#2 Normality: Both variables are normally distributed.
#3 Homoscedasticity: The variance of one variable is stable across the range of the other variable.

# Kontrola missing values
sum(is.na(ProjectMarsV1_1$mic_mean)) # Check missing values for mic_mean
sum(is.na(ProjectMarsV1_1$lermean)) # Check missing values for ler_mean

correlation <- cor(ProjectMarsV1_1$mic_mean, ProjectMarsV1_1$lermean, use = "complete.obs")
print(correlation)

#1 LINEARITY:
# Scatter plot for linearity and homoscedasticity
ggplot(ProjectMarsV1_1, aes(x = mic_mean, y = lermean)) +
  geom_point() +
  geom_smooth(method = lm) +
  theme_minimal()

# Máme tam extrémní outliery - zkusíme je vyjmout - POZOR! Toto je velmi tricky - outliery bychom měli vyjímat jen v případě, že to dává smysl z pohledu výzkumné otázky a designu!

ProjectMarsV1_1_outliers <- read_excel("ProjectMarsV1.1_wo_extreme_outliers.xlsx", na = "NA")
correlation <- cor(ProjectMarsV1_1_outliers$mic_mean, ProjectMarsV1_1_outliers$lermean, use = "complete.obs")
print(correlation)

ggplot(ProjectMarsV1_1_outliers, aes(x = mic_mean, y = lermean)) +
  geom_point() +
  geom_smooth(method = lm) +
  theme_minimal()

# I tak ale pořád špatné, pojďme se podívat na další předpoklady:

#2 NORMALITY
hist(ProjectMarsV1_1$mic_mean, main = "Histogram of MIC Mean", xlab = "MIC Mean")
hist(ProjectMarsV1_1$lermean, main = "Histogram of LER Mean", xlab = "LER Mean")

# Histogram moc normálně nevypadá - zkontrolujeme matematicky:

shapiro.test(ProjectMarsV1_1$mic_mean)
shapiro.test(ProjectMarsV1_1$lermean)

# Chceme p hodnotu v čitelnějším formátu: 
sw_test_mic_mean <- shapiro.test(ProjectMarsV1_1$mic_mean)
formatted_p_value <- format(sw_test_mic_mean$p.value, scientific = FALSE)
print(formatted_p_value)
# SW test vyšel signifikantní --> obě proměnné nejsou normálně rozložené --> nelze využít parametrický test

# Musíme využít neparametrické testy:
cor.test(ProjectMarsV1_1$mic_mean, ProjectMarsV1_1$lermean, method = "spearman") # méně sensitivní jak Pearson, pro velmi velké datasety
cor.test(ProjectMarsV1_1$mic_mean, ProjectMarsV1_1$lermean, method = "kendall") # méně sensitivní jak Pearson a Spearmen, ale pokud máme velké outliery --> konzervativnější


# POROVNÁNÍ S SPSS a Excel

# ------------------------------------------------------------------------------
# (D) kombinace s jiným datasetem --------------------------------------------
# ------------------------------------------------------------------------------
list.files()
PolityProject <- read_excel("polityproject_5.xlsx", na = "NA")

# Perform a full outer join based on 'ccode' and 'year'
combined_dataframe <- full_join(ProjectMarsV1_1, PolityProject, c("statename" = "country", "yrstart" = "year"))

# Inner Join: Combines rows from both datasets where there are matching values in both. This will only include entries that have a ccode present in both datasets.
# Outer Join: Combines all rows from both datasets, filling in missing values with NaN where there is no match. This includes all entries from both datasets, regardless of whether there is a matching ccode.
# Left/Right Join: Combines all rows from the left/right dataset with the matched rows from the right/left dataset. Entries from the left/right dataset without a match in the right/left dataset will have NaN for the missing values.

# Diagram

summary(combined_dataframe)
describe(combined_dataframe[c("mic_mean", "bpi", "lermean", "ngroups", "polity2")])
sum(is.na(combined_dataframe$mic_mean)) # POZOR! hondě NAs!
sum(is.na(combined_dataframe$polity2))
